@@ -3,6 +3,8 @@ from .. import spectrum as rc2spectrum
 from .utils.ramanshift_to_wavelength import (abs_nm_to_shift_cm_1_dict,
                                              shift_cm_1_to_abs_nm_dict)
 
+from typing import Final
+
 PST_RS_dict = {620.9: 16, 795.8: 10, 1001.4: 100, 1031.8: 27, 1155.3: 13, 1450.5: 8,
                1583.1: 12, 1602.3: 28, 2852.4: 9, 2904.5: 13, 3054.3: 32}
 
@@ -535,7 +537,13 @@ neon_wl_D3_3 = [
     836.57464, 837.7607, 846.33569, 849.53591, 854.46952, 857.13535, 859.12583,
     863.46472, 870.41122, 877.16575, 878.37539, 885.38669, 891.95007, 898.85564,
     898.85564, 914.8672, 920.17588, 927.55191, 930.08532, 932.65072, 937.33079,
-    942.53797, 945.9211, 948.66825, 953.4164, 954.74052, 966.542,
+    942.53797, 945.9211, 948.66825, 953.4164, 954.74052, 966.542
 ]
 
 neon_wl_D3_3_dict = dict(zip(neon_wl_D3_3, [1]*len(neon_wl_D3_3)))
+
+NEON_WL: Final = {
+    785: neon_wl_785_nist_dict,
+    633: neon_wl_633_nist_dict,
+    532: neon_wl_532_nist_dict
+}
