@@ -1,10 +1,8 @@
-#!/usr/bin/env python3
-
 from typing import Union
 
 import numpy as np
 from numpy.typing import NDArray
-from pydantic import validate_arguments
+from pydantic import validate_call
 
 from ramanchada2.misc.spectrum_deco import add_spectrum_filter
 
@@ -12,7 +10,7 @@ from ..spectrum import Spectrum
 
 
 @add_spectrum_filter
-@validate_arguments(config=dict(arbitrary_types_allowed=True))
+@validate_call(config=dict(arbitrary_types_allowed=True))
 def __add__(
         old_spe: Spectrum,
         new_spe: Spectrum,
