@@ -1,15 +1,14 @@
-#!/usr/bin/env python3
-
 import numpy as np
-from pydantic import validate_arguments, PositiveInt
+from pydantic import PositiveInt, validate_call
 from scipy import signal
 
 from ramanchada2.misc.spectrum_deco import add_spectrum_filter
+
 from ..spectrum import Spectrum
 
 
 @add_spectrum_filter
-@validate_arguments(config=dict(arbitrary_types_allowed=True))
+@validate_call(config=dict(arbitrary_types_allowed=True))
 def moving_average(old_spe: Spectrum,
                    new_spe: Spectrum, /,
                    window_size: PositiveInt = 10):
@@ -17,8 +16,12 @@ def moving_average(old_spe: Spectrum,
     Moving average filter.
 
     Args:
+        old_spe: internal use only
+        new_spe: internal use only
         window_size:
             `int`, optional, default is `10`.
+
+    Returns: modified Spectrum
     """
     y = [np.average(old_spe.y[i:min(i + window_size, len(old_spe.y))])
          for i in range(len(old_spe.y))]
@@ -26,8 +29,19 @@ def moving_average(old_spe: Spectrum,
 
 
 @add_spectrum_filter
-@validate_arguments(config=dict(arbitrary_types_allowed=True))
+@validate_call(config=dict(arbitrary_types_allowed=True))
 def moving_average_convolve(old_spe: Spectrum,
                             new_spe: Spectrum, /,
                             window_size: PositiveInt = 10):
+    """
+    Moving average filter.
+
+    Args:
+        old_spe: internal use only
+        new_spe: internal use only
+        window_size:
+            `int`, optional, default is `10`.
+
+    Returns: modified Spectrum
+    """
     new_spe.y = signal.convolve(old_spe.y, np.ones(window_size)/window_size, mode='same')
