@@ -1,12 +1,12 @@
 import numpy as np
-from pydantic import PositiveInt, validate_arguments
+from pydantic import PositiveInt, validate_call
 
 from ramanchada2.misc.spectrum_deco import add_spectrum_filter
 
 from ..spectrum import Spectrum
 
 
-@validate_arguments(config=dict(arbitrary_types_allowed=True))
+@validate_call(config=dict(arbitrary_types_allowed=True))
 def _moving_median(s,
                    window_size: PositiveInt = 10):
     y = ([np.median(s[:window_size]) for i in range(window_size)] +
@@ -17,25 +17,44 @@ def _moving_median(s,
 
 
 @add_spectrum_filter
-@validate_arguments(config=dict(arbitrary_types_allowed=True))
+@validate_call(config=dict(arbitrary_types_allowed=True))
 def moving_median(old_spe: Spectrum,
                   new_spe: Spectrum, /,
                   window_size: PositiveInt = 10):
     """
     Moving median filter.
 
+    The resultant spectrum is moving minimum of the input.
+
     Args:
+        old_spe: internal use only
+        new_spe: internal use only
         window_size:
             `int`, optional, default is `10`.
+
+    Returns: modified Spectrum
     """
 
     new_spe.y = _moving_median(old_spe.y, window_size)
 
 
 @add_spectrum_filter
-@validate_arguments(config=dict(arbitrary_types_allowed=True))
+@validate_call(config=dict(arbitrary_types_allowed=True))
 def subtract_moving_median(
         old_spe: Spectrum,
         new_spe: Spectrum,
         window_size: int):
+    """
+    Subtract moving median filter.
+
+    The resultant spectrum is moving minimum of the input subtracted from the input.
+
+    Args:
+        old_spe: internal use only
+        new_spe: internal use only
+        window_size:
+            `int`, optional, default is `10`.
+
+    Returns: modified Spectrum
+    """
     new_spe.y = old_spe.y - _moving_median(old_spe.y, window_size)
