@@ -1,11 +1,9 @@
-#!/usr/bin/env python3
-
 import logging
 from typing import List, Literal, Union
 
 import numpy as np
 from lmfit.models import LinearModel, lmfit_models
-from pydantic import validate_arguments
+from pydantic import validate_call
 
 from ramanchada2.misc.spectrum_deco import (add_spectrum_filter,
                                             add_spectrum_method)
@@ -20,7 +18,7 @@ available_models = ['Gaussian', 'Lorentzian', 'Moffat', 'Voigt', 'PseudoVoigt',
 available_models_type = Literal['Gaussian', 'Lorentzian', 'Moffat', 'Voigt', 'PseudoVoigt', 'Pearson4', 'Pearson7']
 
 
-@validate_arguments(config=dict(arbitrary_types_allowed=True))
+@validate_call(config=dict(arbitrary_types_allowed=True))
 def build_multipeak_model_params(profile: Union[available_models_type, List[available_models_type]],
                                  candidates: PeakCandidateMultiModel,
                                  baseline_model: Literal['linear', None] = 'linear',
@@ -84,7 +82,7 @@ def build_multipeak_model_params(profile: Union[available_models_type, List[avai
 
 
 @add_spectrum_method
-@validate_arguments(config=dict(arbitrary_types_allowed=True))
+@validate_call(config=dict(arbitrary_types_allowed=True))
 def fit_peak_multimodel(spe, /, *,
                         profile: Union[available_models_type, List[available_models_type]],
                         candidates: ListPeakCandidateMultiModel,
@@ -93,13 +91,37 @@ def fit_peak_multimodel(spe, /, *,
                         kwargs_fit={},
                         vary_baseline: bool = False,
                         ) -> FitPeaksResult:
+    """
+    Fit a model based on candidates to the spectrum.
+
+    Args:
+        spe: internal use only
+        profile: str or List[str]
+            possible values are: ["""+str(available_models)+"""]
+        candidates: as provided from find_peak_multipeak
+        no_fit: optional. Defaults to False.
+            If true, do not perform a fit. Result will be the inital guess,
+            based on the data from peak candidates.
+        should_break: optional. Defaults to [False].
+            Use mutability of the python list type to be able to externaly
+            break the minimization procedure.
+        kwargs_fit: optional
+            kwargs for fit function
+        vary_baseline: optional. Defaults to False.
+            If False baseline will not be a free parameter and its amplitude
+            will be taken from the peak candidates.
+
+    Returns:
+        FitPeaksResult: groups of fitted peaks
+    """
+
     def iter_cb(params, iter, resid, *args, **kws):
         return should_break[0]
     if no_fit:
         kwargs_fit = dict(kwargs_fit)
         kwargs_fit['max_nfev'] = 1
     fit_res = FitPeaksResult()
-    for group in candidates.__root__:
+    for group in candidates.root:
         mod, par = build_multipeak_model_params(profile=profile, candidates=group)
         idx = (group.boundaries[0] < spe.x) & (spe.x < group.boundaries[1])
         x = spe.x[idx]
@@ -118,7 +140,7 @@ def fit_peak_multimodel(spe, /, *,
 
 
 @add_spectrum_filter
-@validate_arguments(config=dict(arbitrary_types_allowed=True))
+@validate_call(config=dict(arbitrary_types_allowed=True))
 def fit_peaks_filter(
         old_spe: Spectrum,
         new_spe: Spectrum, /, *args,
@@ -127,9 +149,15 @@ def fit_peaks_filter(
         **kwargs,
         ):
     """
-    Write fit result as metadata.
+    Same as `fit_peak_multipeak` but the result is stored as metadata in the returned spectrum.
+
+    Args:
+        old_spe: internal use only
+        new_spe: internal use only
+        should_break: same as in fit_peaks_multipeak
+        *args, **kwargs: same as `fit_peaks_multipeak`
     """
-    cand_groups = ListPeakCandidateMultiModel.validate(old_spe.result)
+    cand_groups = ListPeakCandidateMultiModel.model_validate(old_spe.result)
     new_spe.result = old_spe.fit_peak_multimodel(*args,  # type: ignore
                                                  candidates=cand_groups,
                                                  should_break=should_break,
